==> MIDITrail-Ver.1.2.0-Windows_src.zip: MIDITrail/MIDITrail/MTGraphicCfgDlg.h <==
//******************************************************************************
//
// MIDITrail / MTGraphicCfgDlg
//
// OtBbNݒ_CAONX
//
// Copyright (C) 2010 WADA Masashi. All Rights Reserved.
//
//******************************************************************************

#pragma once

#include "YNBaseLib.h"
#include "DXRenderer.h"

using namespace YNBaseLib;


//******************************************************************************
// OtBbNݒ`
//******************************************************************************
//A`GCAVOF}`TvʃftHg
#define MT_GRAPHIC_MULTI_SAMPLE_TYPE_DEF  (0)  //OFF


//******************************************************************************
// OtBbNݒ_CAONX
//******************************************************************************
class MTGraphicCfgDlg
{
public:

	//RXgN^^fXgN^
	MTGraphicCfgDlg(void);
	virtual ~MTGraphicCfgDlg(void);

	//A`GCAVOT|[gݒ
	void SetAntialiasSupport(unsigned long multiSampleType, bool isSupport);

	//\F_CAO܂ŐԂȂ
	int Show(HWND hParentWnd);

	//p[^ύXmF
	bool IsCahnged();

private:

	//EBhEvV[Wp|C^
	static MTGraphicCfgDlg* m_pThis;

	//AvP[VCX^X
	HINSTANCE m_hInstance;

	//ݒt@C
	YNConfFile m_ConfFile;

	//R{{bNX̃EBhEnh
	HWND m_hComboMultiSampleType;
	bool m_MultSampleTypeSupport[DX_MULTI_SAMPLE_TYPE_MAX+1];

	//A`GCAVOݒ
	unsigned long m_MultiSampleType;

	//XVtO
	bool m_isCahnged;

	//EBhEvV[W
	static INT_PTR CALLBACK _WndProc(HWND, UINT, WPARAM, LPARAM);
	INT_PTR _WndProcImpl(const HWND hWnd, const UINT message, const WPARAM wParam, const LPARAM lParam);

	//_CAO\O
	int _OnInitDlg(HWND hDlg);

	//ݒt@C
	int _InitConfFile();

	//ݒt@Cǂݍ
	int _LoadConf();

	//foCXIR{{bNX
	int _InitComboMultiSampleType(HWND hCombo, unsigned long selMultiSampleType);

	//ۑ
	int _Save();

};

==> MIDITrail-Ver.1.4.0-Windows_src.zip: MIDITrail/MIDITrail/MTGraphicCfgDlg.h <==
//******************************************************************************
//
// MIDITrail / MTGraphicCfgDlg
//
// OtBbNݒ_CAONX
//
// Copyright (C) 2010-2022 WADA Masashi. All Rights Reserved.
//
//******************************************************************************

#pragma once

#include "YNBaseLib.h"
#include "DXRenderer.h"

using namespace YNBaseLib;


//******************************************************************************
// OtBbNݒ`
//******************************************************************************
//A`GCAVOF}`TvʃftHg
#define MT_GRAPHIC_MULTI_SAMPLE_TYPE_DEF  (0)  //OFF


//******************************************************************************
// OtBbNݒ_CAONX
//******************************************************************************
class MTGraphicCfgDlg
{
public:

	//RXgN^^fXgN^
	MTGraphicCfgDlg(void);
	virtual ~MTGraphicCfgDlg(void);

	//A`GCAVOT|[gݒ
	void SetAntialiasSupport(unsigned long multiSampleType, bool isSupport);

	//\F_CAO܂ŐԂȂ
	int Show(HWND hParentWnd);

	//p[^ύXmF
	bool IsChanged();

private:

	//EBhEvV[Wp|C^
	static MTGraphicCfgDlg* m_pThis;

	//AvP[VCX^X
	HINSTANCE m_hInstance;

	//EBhEnh
	HWND m_hWnd;

	//ݒt@C
	YNConfFile m_ConfFile;

	//R{{bNX̃EBhEnh
	HWND m_hComboMultiSampleType;
	bool m_MultSampleTypeSupport[DX_MULTI_SAMPLE_TYPE_MAX+1];

	//wi摜t@CpXGfBbg{bNX̃EBhEnh
	HWND m_hEditImageFilePath;
	
	//lg嗦GfBbg{bNX̃EBhEnh
	HWND m_hEditQuarterNoteLengthMag;

	//A`GCAVOݒ
	unsigned long m_MultiSampleType;

	//wi摜t@CpX
	WCHAR m_ImageFilePath[_MAX_PATH];
	
	//lg嗦
	int m_QuarterNoteLengthMag;

	//XVtO
	bool m_isChanged;

	//EBhEvV[W
	static INT_PTR CALLBACK _WndProc(HWND, UINT, WPARAM, LPARAM);
	INT_PTR _WndProcImpl(const HWND hWnd, const UINT message, const WPARAM wParam, const LPARAM lParam);

	//_CAO\O
	int _OnInitDlg(HWND hDlg);

	//ݒt@C
	int _InitConfFile();

	//ݒt@Cǂݍ
	int _LoadConf();

	//foCXIR{{bNX
	int _InitComboMultiSampleType(HWND hCombo, unsigned long selMultiSampleType);

	//wi摜t@CpX
	int _InitBackgroundImageFilePath();
	
	//lݒ菉
	int _InitQuarterNote();

	//ۑ
	int _Save();

	//wi摜t@CpXuEY{^
	int _OnBtnBrowse();

	//摜t@CI
	int _SelectImageFile(WCHAR* pFilePath, unsigned long bufSize, bool* pIsSelected);

};
